API Version: 4.0
Library Version: 4.18.6
Generated by gi-docgen 2023.3
since: 4.0
struct GdkToplevelSize { /* No available fields */ }
Contains information that is useful to compute the size of a toplevel.
Available since: 4.0
Retrieves the bounds the toplevel is placed within.
Sets the minimum size of the toplevel.
Sets the shadows size of the toplevel.
Sets the size the toplevel prefers to be resized to.
Content